@@ -1,11 +1,12 @@
 #ifndef ACCESSPOINTGUI_H
 #define ACCESSPOINTGUI_H
 
-#include <QtGui/QDialog>
+#include <QtGui/QMainWindow>
+#include <QtGui/QCloseEvent>
 #include "mobilehotspotconfiguration.h"
 #include "ui_accesspointgui.h"
 
-class AccessPointGUI : public QDialog
+class AccessPointGUI : public QMainWindow
 {
     Q_OBJECT
 
@@ -15,10 +16,15 @@ public:
     void setConfiguration(MobileHotspotConfiguration &configuration);
     void configuration(MobileHotspotConfiguration *configuration);
 
+protected:
+	void closeEvent(QCloseEvent* event);
+
 private:
     Ui::AccessPointGUIClass ui;
     QString validKey();
 
+signals:
+	void windowClosed();
 };
 
 #endif // ACCESSPOINTGUI_H
