@@ -10,7 +10,6 @@
 #include "mobilehotspotconfiguration.h"
 #include "commandhelper.h"
 #include "dbushelper.h"
-#include "apnhelper.h"
 #include "hotspothelper.h"
 
 
@@ -138,13 +137,13 @@ int HotspotHelper::enableInternetConnection(MobileHotspotConfiguration &configur
 	return 0;
 }
 
-int HotspotHelper::prepareUSBInterface(MobileHotspotConfiguration &configuration){
+int HotspotHelper::prepareUSBInterface(QString usbMAC, QString lanNetwork){
 	/* -1=fail, 0=ok */
 	qDebug("** Preparing USB interface **");
 	int ret;
 
 	/** Disable USB interface - may fail, not fatal unless timeout **/
-	ret = disableUSBInterface(configuration);
+	ret = disableUSBInterface();
 	if(ret == -2){
 		qDebug("Error (timeout) while disabling the USB interface");
 		return -1;
@@ -153,8 +152,8 @@ int HotspotHelper::prepareUSBInterface(MobileHotspotConfiguration &configuration
 		qDebug("WARNING :  Was not able to disable the USB interface");
 
 	/** Change USB MAC if necessary **/
-	if(configuration.usbMAC != ""){
-		ret = setUSBMAC(configuration);
+	if(usbMAC != ""){
+		ret = setUSBMAC(usbMAC);
 		if(ret == -2){
 			qDebug("Error (timeout) while changing the USB MAC");
 			return -1;
@@ -164,7 +163,7 @@ int HotspotHelper::prepareUSBInterface(MobileHotspotConfiguration &configuration
 	}
 
 	/** Enable USB interface **/
-	ret = enableUSBInterface(configuration);
+	ret = enableUSBInterface(lanNetwork);
 	if(ret != 0){
 		qDebug("Error while enabling the USB interface");
 		return -1;
@@ -173,12 +172,12 @@ int HotspotHelper::prepareUSBInterface(MobileHotspotConfiguration &configuration
 	return 0;
 }
 
-int HotspotHelper::setUSBMAC(MobileHotspotConfiguration &configuration){
+int HotspotHelper::setUSBMAC(QString usbMAC){
 	/* -1=fail, -2=timeout, 0=ok */
 	qDebug("*** Changing USB MAC ***");
 	int ret, tries;
 	bool cmdret, trying;
-	QString cmd("/sbin/ifconfig "); cmd += configuration.INTERFACE_USB; cmd += " hw ether "; cmd += configuration.usbMAC;
+	QString cmd("/sbin/ifconfig "); cmd += MobileHotspotConfiguration::INTERFACE_USB; cmd += " hw ether "; cmd += usbMAC;
 	cmdret = CommandHelper::executeCommand(cmd, &ret);
 	if( (! cmdret) || (cmdret && ret != 0) ){
 		qDebug("FAILURE : Cannot change USB MAC");
@@ -188,8 +187,8 @@ int HotspotHelper::setUSBMAC(MobileHotspotConfiguration &configuration){
 	while(trying && tries < MAX_TRIES){
 		tries++;
 		QString res;
-		CommandHelper::executeCommandWithStdOut(QString("/sbin/ifconfig ") + configuration.INTERFACE_USB, &ret, &res);
-		if(res.toLower().count(configuration.usbMAC.toLower()) > 0)
+		CommandHelper::executeCommandWithStdOut(QString("/sbin/ifconfig ") + MobileHotspotConfiguration::INTERFACE_USB, &ret, &res);
+		if(res.toLower().count(usbMAC.toLower()) > 0)
 			trying = false;
 		else
 			CommandHelper::executeCommand("sleep 1");
@@ -258,12 +257,12 @@ void HotspotHelper::unloadNokiaUSB(){
 		qDebug("WARNING : Was not able to unload g_file_storage");
 }
 
-int HotspotHelper::disableUSBInterface(MobileHotspotConfiguration &configuration){
+int HotspotHelper::disableUSBInterface(){
 	/* -1=fail, -2=timeout, 0=ok */
 	qDebug("** Disabling USB interface **");
 	int ret, tries;
 	bool cmdret, trying;
-	QString cmd("/sbin/ifconfig "); cmd += configuration.INTERFACE_USB; cmd += " down";
+	QString cmd("/sbin/ifconfig "); cmd += MobileHotspotConfiguration::INTERFACE_USB; cmd += " down";
 	cmdret = CommandHelper::executeCommand(cmd, &ret);
 	if( (! cmdret) || (cmdret && ret != 0) ){
 		qDebug("FAILURE : Cannot disable USB interface");
@@ -274,7 +273,7 @@ int HotspotHelper::disableUSBInterface(MobileHotspotConfiguration &configuration
 		tries++;
 		QString res;
 		CommandHelper::executeCommandWithStdOut("/sbin/ifconfig", &ret, &res);
-		if(res.count(configuration.INTERFACE_USB) < 1)
+		if(res.count(MobileHotspotConfiguration::INTERFACE_USB) < 1)
 			trying = false;
 		else
 			CommandHelper::executeCommand("sleep 1");
@@ -286,13 +285,13 @@ int HotspotHelper::disableUSBInterface(MobileHotspotConfiguration &configuration
 	return 0;
 }
 
-int HotspotHelper::enableUSBInterface(MobileHotspotConfiguration &configuration){
+int HotspotHelper::enableUSBInterface(QString lanNetwork){
 	/* -1=fail, -2=timeout, 0=ok */
 	qDebug("** Enabling USB interface **");
 	int tries, ret;
 	bool cmdret, trying;
-	QString cmd("/sbin/ifconfig "); cmd += configuration.INTERFACE_USB; cmd += " ";
-	cmd += configuration.lanNetwork; cmd += "1 netmask 255.255.255.0 up";
+	QString cmd("/sbin/ifconfig "); cmd += MobileHotspotConfiguration::INTERFACE_USB; cmd += " ";
+	cmd += lanNetwork; cmd += "1 netmask 255.255.255.0 up";
 	cmdret = CommandHelper::executeCommand(cmd, &ret);
 	if( (! cmdret) || (cmdret && ret != 0) ){
 		qDebug("FAILURE : Cannot enable USB interface");
@@ -303,7 +302,7 @@ int HotspotHelper::enableUSBInterface(MobileHotspotConfiguration &configuration)
 		tries++;
 		QString res;
 		CommandHelper::executeCommandWithStdOut("/sbin/ifconfig", &ret, &res);
-		if(res.count(configuration.INTERFACE_USB) > 0)
+		if(res.count(MobileHotspotConfiguration::INTERFACE_USB) > 0)
 			trying = false;
 		else
 			CommandHelper::executeCommand("sleep 1");
@@ -640,13 +639,13 @@ int HotspotHelper::setWifiNetwork(MobileHotspotConfiguration &configuration){
 	return 0;
 }
 
-int HotspotHelper::unprepareUSBInterface(MobileHotspotConfiguration &configuration){
+int HotspotHelper::unprepareUSBInterface(){
 	/** -1=fail, 0=ok */
 	qDebug("** Unpreparing USB interface **");
 	int res = 0, ret;
 
 	/** Disable USB interface **/
-	ret = HotspotHelper::disableUSBInterface(configuration);
+	ret = HotspotHelper::disableUSBInterface();
 	if(ret != 0){
 		qDebug("Error while disabling USB interface");
 		res = -1;
