@@ -3,6 +3,7 @@
 
 #include <QtCore/QString>
 #include <QtCore/QStringList>
+#include <QtCore/QProcess>
 #include "dbushelper.h"
 #include "mobilehotspotconfiguration.h"
 
@@ -26,9 +27,9 @@ public:
     static void unloadStandardUSB();
     static int loadNokiaUSB();
     static void unloadNokiaUSB();
-    static int prepareUSBInterface(MobileHotspotConfiguration &configuration);
+    static int prepareUSBInterface(QString usbMAC, QString lanNetwork);
     static int prepareWifiInterface(MobileHotspotConfiguration &configuration);
-    static int unprepareUSBInterface(MobileHotspotConfiguration &configuration);
+    static int unprepareUSBInterface();
     static int unprepareWifiInterface(MobileHotspotConfiguration &configuration);
     static int startDnsMasq(MobileHotspotConfiguration &configuration, QProcess *dnsmasqProcess);
     static int stopDnsMasq(MobileHotspotConfiguration &configuration, QProcess *dnsmasqProcess);
@@ -39,9 +40,9 @@ private:
 	static int loadModule(QString moduleName);
 	static int unloadModule(QString moduleName);
 	static QStringList getSystemModules();
-	static int enableUSBInterface(MobileHotspotConfiguration &configuration);
-	static int setUSBMAC(MobileHotspotConfiguration &configuration);
-	static int disableUSBInterface(MobileHotspotConfiguration &configuration);
+	static int enableUSBInterface(QString lanNetwork);
+	static int setUSBMAC(QString usbMAC);
+	static int disableUSBInterface();
 	static int enableWifiInterface(MobileHotspotConfiguration &configuration);
 	static int disableWifiInterface(MobileHotspotConfiguration &configuration);
 	static int setPowerManagement(MobileHotspotConfiguration &configuration, bool management);
