@@ -1,3 +1,5 @@
+#include <QtGui/QMainWindow>
+#include <QtGui/QMenuBar>
 #include <QtCore/QString>
 #include <QtCore/QList>
 #include <QtCore/QStringList>
@@ -13,13 +15,11 @@
 
 
 InternetAccessGUI::InternetAccessGUI(QWidget *parent)
-    : QDialog(parent)
+    : QMainWindow(parent)
 {
 	ui.setupUi(this);
-	ui.lst2G3G->addItem(tr("No change"), "ignore");
-	ui.lst2G3G->addItem(tr("2G only"), "2g");
-	ui.lst2G3G->addItem(tr("3G only"), "3g");
-	ui.lst2G3G->addItem(tr("2G/3G"), "2g3g");
+	this->setAttribute(Qt::WA_Maemo5StackedWindow);
+
 	waitingForAPNs = false;
 	gprsOnly = false;
 	currentIAPID = "";
@@ -27,24 +27,27 @@ InternetAccessGUI::InternetAccessGUI(QWidget *parent)
 
 InternetAccessGUI::~InternetAccessGUI()
 {
+
+}
+
+void InternetAccessGUI::closeEvent(QCloseEvent* event){
+	// Signal that the GUI is closed
+	if(menuBar() != 0)
+		menuBar()->clear(); // Solves a bug where menubar in child gui is kept in parent gui
+
 	if(waitingForAPNs){
 		waitingForAPNs = false;
 		apnsCancelRequest();
 		apnsDisableSignal();
 	}
+
+	emit windowClosed();
+	event->accept();
 }
 
 void InternetAccessGUI::setConfiguration(MobileHotspotConfiguration &configuration){
 	ui.txtNetwork->setText(configuration.lanNetwork + "0");
 	ui.chkInternet->setChecked(configuration.internetEnabled);
-	if(configuration.enforcement2g3g == ENFORCEMENT_2G3G_IGNORE)
-		ui.lst2G3G->setCurrentIndex(0);
-	else if(configuration.enforcement2g3g == ENFORCEMENT_2G3G_2G)
-		ui.lst2G3G->setCurrentIndex(1);
-	else if(configuration.enforcement2g3g == ENFORCEMENT_2G3G_3G)
-		ui.lst2G3G->setCurrentIndex(2);
-	else
-		ui.lst2G3G->setCurrentIndex(3);
 
 	gprsOnly = configuration.lanInterface == configuration.INTERFACE_WLAN;
 	currentIAPID = configuration.internetAPID;
@@ -58,6 +61,7 @@ void InternetAccessGUI::updateAPNs(){
 	if(apnsRequest()){
 		waitingForAPNs = true;
 		ui.lstAPN->setEnabled(false);
+		ui.btnRefresh->setEnabled(false);
 		QTimer::singleShot(TIME_APNS, this, SLOT(apnsTimeout()));
 	}
 	else{
@@ -81,14 +85,6 @@ void InternetAccessGUI::configuration(MobileHotspotConfiguration *configuration)
 	}
 	configuration->lanNetwork = validNetwork();
 	configuration->internetEnabled = ui.chkInternet->isChecked();
-	if(ui.lst2G3G->currentIndex() == 0)
-		configuration->enforcement2g3g = ENFORCEMENT_2G3G_IGNORE;
-	else if(ui.lst2G3G->currentIndex() == 1)
-		configuration->enforcement2g3g = ENFORCEMENT_2G3G_2G;
-	else if(ui.lst2G3G->currentIndex() == 2)
-		configuration->enforcement2g3g = ENFORCEMENT_2G3G_3G;
-	else
-		configuration->enforcement2g3g = ENFORCEMENT_2G3G_DOUBLE;
 }
 
 void InternetAccessGUI::apnsDisableSignal(){
@@ -156,6 +152,7 @@ void InternetAccessGUI::apnsTimeout(){
 	apnsDisableSignal();
 	waitingForAPNs = false;
 	ui.lstAPN->setEnabled(true);
+	ui.btnRefresh->setEnabled(true);
 	int configIndex = 0;
 	QListIterator<QStringList> iterator(apns);
 	while(iterator.hasNext()){
