@@ -21,11 +21,6 @@ int main(int argc, char *argv[])
     QApplication::setApplicationName("Qt Mobile Hotspot");
     QApplication::setOverrideCursor(QCursor(Qt::BlankCursor));
 
-    QString lang = QLocale::system().name();
-    QTranslator translator;
-    translator.load(lang, "./lang");
-    app.installTranslator(&translator);
-
     MobileHotspotGUI gui;
     gui.show();
 
