@@ -7,6 +7,7 @@
 
 
 #define GCONF "/apps/qtmobilehotspot"
+#define GCONF_LANGUAGE GCONF "/lang"
 #define GCONF_APNAME GCONF "/name"
 #define GCONF_ENCRYPTION GCONF "/encryption"
 #define GCONF_KEY GCONF "/key"
@@ -17,17 +18,16 @@
 #define GCONF_APTYPE GCONF "/aptype"
 #define GCONF_NETWORK GCONF "/network"
 #define GCONF_INTERNET GCONF "/internet"
-#define GCONF_2G3G	GCONF "/2g3g"
+
 #define PERSISTENT_FOLDER "/home/user/.qtmobilehotspot"
 #define FILE_USBMAC PERSISTENT_FOLDER "/usb.mac"
 
+#define NO_LANGUAGE_SELECTED "?"
+#define DEFAULT_LANGUAGE ""
 
-enum Enforcement_2G3G{
-	ENFORCEMENT_2G3G_2G,
-	ENFORCEMENT_2G3G_3G,
-	ENFORCEMENT_2G3G_DOUBLE,
-	ENFORCEMENT_2G3G_IGNORE
-};
+#define APN_TYPE_INFRA     "WLAN_INFRA" // = GCONF_APN_TYPE_INFRA from APNHelper
+#define APN_TYPE_ADHOC     "WLAN_ADHOC" // = GCONF_APN_TYPE_ADHOC from APNHelper
+#define APN_TYPE_GPRS      "GPRS" // = GCONF_APN_TYPE_GPRS from APNHelper
 
 
 class MobileHotspotConfiguration : public QObject
@@ -41,9 +41,8 @@ public:
 	static const QString INTERFACE_USB;
 	static const QString INTERFACE_GPRS;
 
-	QString hotspotName, encryptionType, encryptionKey, lanInterface, lanNetwork, internetAPName, internetAPType, internetAPID, usbMAC;
+	QString language, hotspotName, encryptionType, encryptionKey, lanInterface, lanNetwork, internetAPName, internetAPType, internetAPID, usbMAC;
 	bool internetEnabled, cycleWlanDriver;
-	Enforcement_2G3G enforcement2g3g;
 
 public:
 	MobileHotspotConfiguration(QObject *parent = 0);
