@@ -22,20 +22,30 @@
 #include "mobilehotspotplugin.h"
 #include "dbushelper.h"
 #include "hotspothelper.h"
+#include "pluginscontrolgui.h"
 #include "accesspointgui.h"
 #include "internetaccessgui.h"
+#include "languagegui.h"
 #include "mobilehotspotgui.h"
 
 
 MobileHotspotGUI::MobileHotspotGUI(QWidget *parent)
     : QMainWindow(parent)
 {
+	qApp->installTranslator(&translator);
+	ui.setupUi(this);
+	this->setAttribute(Qt::WA_Maemo5StackedWindow);
+
 	dnsmasqProcess = 0;
 	loadPlugins();
 	sortPlugins();
-	ui.setupUi(this);
-	displayPlugins(false);
+
 	configuration.load();
+	if(configuration.language == NO_LANGUAGE_SELECTED)
+		configureLanguage();
+	else
+		configureLanguageFinished(false);
+
 	updateDisplayedConfiguration();
 }
 
@@ -59,6 +69,10 @@ void MobileHotspotGUI::closeEvent(QCloseEvent* event){
 }
 
 void MobileHotspotGUI::loadPlugins(){
+	plugins.clear();
+	sortedPlugins.clear();
+	pluginsTranslatorsBaseNames.clear();
+
 	QDir dir("./plugins");
 	QStringList list = dir.entryList(QDir::Files | QDir::NoSymLinks);
 	QStringListIterator iterator(list);
@@ -74,11 +88,8 @@ void MobileHotspotGUI::loadPlugins(){
 				if(plugins.contains(name))
 					qDebug( (QString("WARNING : plugin name ") + name + " is already taken").toAscii().data());
 				else{
+					pluginsTranslatorsBaseNames.insert(name, QFileInfo(dir, filename).completeBaseName());
 					plugins.insert(name, plugin);
-					QString lang = (QFileInfo(dir, filename).completeBaseName() + "-") + QLocale::system().name();
-					QTranslator *translator = new QTranslator();
-					translator->load(lang, "./lang");
-					plugin->setTranslator(translator);
 					qDebug( (QString("Loaded plugin ") + name).toAscii().data() );
 				}
 			}
@@ -109,35 +120,56 @@ void MobileHotspotGUI::sortPlugins(){
 	}
 }
 
-void MobileHotspotGUI::displayPlugins(bool running){
-	ui.menuPlugins->clear();
-	QList<MobileHotspotPlugin*> values = plugins.values();
-	QListIterator<MobileHotspotPlugin*> iterator(values);
-	while(iterator.hasNext()){
-		MobileHotspotPlugin *plugin = iterator.next();
-		if( (running && plugin->displayNameRunning()) || ((! running) && plugin->displayNameStopped()) ){
-			qApp->installTranslator(plugin->translator());
-				QAction *action = ui.menuPlugins->addAction(plugin->displayedName());
-			qApp->removeTranslator(plugin->translator());
-			action->setData(plugin->name());
-			QObject::connect(action, SIGNAL(triggered()), this, SLOT(pluginTriggered()));
-		}
-	}
+void MobileHotspotGUI::configurePlugins(){
+	pluginsControlGUI = new PluginsControlGUI(this);
+	pluginsControlGUI->setConfiguration(&configuration, ui.btnStop->isEnabled(), &plugins, &sortedPlugins);
+	connect(pluginsControlGUI, SIGNAL(windowClosed()),
+		this, SLOT(configurePluginsFinished()));
+	pluginsControlGUI->show();
 }
 
-void MobileHotspotGUI::pluginTriggered(){
-	QObject *sender = const_cast<QObject*>(QObject::sender());
-	QAction *action = static_cast<QAction*>(sender);
-	QString name = action->data().toString();
-	if(! plugins.contains(name)){
-			qDebug("Weird error, plugin action linked to no plugin ?");
+void MobileHotspotGUI::configurePluginsFinished(){
+	// Some code that is run after the closing of the Configure Plugins window
+}
+
+void MobileHotspotGUI::configureLanguage(){
+	LanguageGUI dlg;
+	dlg.setConfiguration(configuration);
+	if(dlg.exec() != dlg.Accepted){
+		if(configuration.language != NO_LANGUAGE_SELECTED)
 			return;
+		else
+			configuration.language = DEFAULT_LANGUAGE;
 	}
-	MobileHotspotPlugin *plugin = plugins.value(name);
-	qDebug( (QString("Plugin configure : ") + name).toAscii().data() );
-	qApp->installTranslator(plugin->translator());
-		plugin->configure(configuration, ui.btnStop->isEnabled());
-	qApp->removeTranslator(plugin->translator());
+	else
+		dlg.configuration(&configuration);
+	configureLanguageFinished(true);
+}
+
+void MobileHotspotGUI::configureLanguageFinished(bool saveConfiguration){
+	if(saveConfiguration)
+		configuration.save();
+
+	QString lang = configuration.language;
+	if(lang != DEFAULT_LANGUAGE)
+		translator.load(lang, "./lang", "_", ".qtmh.qm");
+	else
+		translator.load("", "", "", "");
+
+	QListIterator<MobileHotspotPlugin*> iterator(plugins.values());
+	while(iterator.hasNext()){
+		MobileHotspotPlugin *plugin = iterator.next();
+		QString name = plugin->name();
+		QTranslator *trans = plugin->translator();
+
+		if(lang != DEFAULT_LANGUAGE)
+			trans->load( (pluginsTranslatorsBaseNames.value(name) + "-") + lang, "./lang", "_", ".qm");
+		else
+			trans->load("", "", "", "");
+	}
+
+	ui.retranslateUi(this);
+	updateDisplayedConfiguration();
 }
 
 void MobileHotspotGUI::updateDisplayedConfiguration(){
@@ -149,18 +181,6 @@ void MobileHotspotGUI::updateDisplayedConfiguration(){
 
 	ui.lstInternetAccess->clear();
 	QString s = configuration.internetAPName;
-	if(s != "" && configuration.internetInterface() == configuration.INTERFACE_GPRS){
-		if(configuration.enforcement2g3g != ENFORCEMENT_2G3G_IGNORE){
-			s += " (";
-			if(configuration.enforcement2g3g == ENFORCEMENT_2G3G_2G)
-				s += tr("2G");
-			else if(configuration.enforcement2g3g == ENFORCEMENT_2G3G_3G)
-				s += tr("3G");
-			else
-				s += tr("2G/3G");
-			s += ")";
-		}
-	}
 	ui.lstInternetAccess->addItem(s);
 	ui.lstInternetAccess->addItem(configuration.internetEnabled ? tr("With internet") : tr("Without internet"));
 	ui.lstInternetAccess->addItem(configuration.lanNetwork + "0");
@@ -171,121 +191,30 @@ void MobileHotspotGUI::updateDisplayedConfiguration(){
 	ui.lstInterfaces->setCurrentIndex(configuration.lanInterface == configuration.INTERFACE_WLAN ? 0 : 1);
 }
 
-void MobileHotspotGUI::usbWindowsAssistant(){
-	QString title = tr("USB For Windows Setup");
-	bool failed = false;
-	QString text;
-	QString interface = configuration.lanInterface;
-	configuration.lanInterface = configuration.INTERFACE_USB;
-
-	try{
-		text = tr("This will help you into installing the USB networking driver into Windows. Please disconnect your N900 from your computer before continuing.");
-		if(QMessageBox::question(this, title, text, QMessageBox::Yes | QMessageBox::Cancel) != QMessageBox::Yes)
-			throw QString();
-
-		text = tr("First, ensure that you have copied the windows-usb-driver folder from /opt/qtmobilehotspot/docs (or QtMobileHotspot-Driver when connected in mass-storage mode) to your computer. If this is not the case, stop this assistant, and copy the folder.");
-		if(QMessageBox::question(this, title, text, QMessageBox::Yes | QMessageBox::Cancel) != QMessageBox::Yes)
-			throw QString();
-
-		text = tr("We are now going to unload every USB module and load the one for USB networking. Ensure that you are disconnected from your PC and that your N900 isn't in any USB mode (no PC-Suite, no mass-storage).");
-		if(QMessageBox::question(this, title, text, QMessageBox::Yes | QMessageBox::Cancel) != QMessageBox::Yes)
-			throw QString();
-
-		HotspotHelper::unloadStandardUSB();
-		HotspotHelper::unloadNokiaUSB();
-		if(HotspotHelper::checkUSBMode() != 0){
-			text = tr("It seems that the USB device is busy. Usually it is due to a USB-mode being active (mass storage / pc-suite). Please stop this mode and try again.");
-			QMessageBox::critical(this, title, text);
-			throw QString();
-		}
-		if(HotspotHelper::loadStandardUSB() != 0){
-			text = tr("The system failed to load the standard g_ether USB module. It may be due to a missing power-kernel or to a system in an inconsistent state. Please try again later.");
-			QMessageBox::critical(this, title, text);
-			throw QString();
-		}
-		if(HotspotHelper::prepareUSBInterface(configuration) != 0){
-			text = tr("The system failed to turn on the USB interface. It may be due to a system in an inconsistent state, please try again later.");
-			QMessageBox::critical(this, title, text);
-			throw QString();
-		}
-
-		text = tr("Everything seems to be fine on your N900. You can now connect it to your computer, then continue. Do not select any USB-mode when asked.");
-		if(QMessageBox::question(this, title, text, QMessageBox::Yes | QMessageBox::Cancel) != QMessageBox::Yes)
-			throw QString();
-
-		text = tr("Are you running Windows 7 / Windows Vista ?");
-		if(QMessageBox::question(this, title, text, QMessageBox::Yes | QMessageBox::No) != QMessageBox::Yes){
-			text = tr("The computer will ask you about drivers. Tell it that you want to do an expert install (pick the driver yourself).");
-			if(QMessageBox::question(this, title, text, QMessageBox::Yes | QMessageBox::Cancel) != QMessageBox::Yes)
-				throw QString();
-
-			text = tr("Now edit the settings in order to make Windows use your windows-usb-driver folder. Make sure not to forget any useful checkbox.");
-			if(QMessageBox::question(this, title, text, QMessageBox::Yes | QMessageBox::Cancel) != QMessageBox::Yes)
-				throw QString();
-		}
-		else{
-			text = tr("The computer will try to install a driver automatically (usually). It will fail, that is normal.");
-			if(QMessageBox::question(this, title, text, QMessageBox::Yes | QMessageBox::Cancel) != QMessageBox::Yes)
-				throw QString();
-
-			text = tr("Now go to the device manager (control panel, system, device manager). You should see an unknown device called Linux Ethernet RNDIS. Right-click on it, and choose Update driver.");
-			if(QMessageBox::question(this, title, text, QMessageBox::Yes | QMessageBox::Cancel) != QMessageBox::Yes)
-				throw QString();
-
-			text = tr("Choose to pick the driver yourself, and tell the program about your windows-usb-driver folder. Do not miss any important checkbox.");
-			if(QMessageBox::question(this, title, text, QMessageBox::Yes | QMessageBox::Cancel) != QMessageBox::Yes)
-				throw QString();
-		}
-
-		text = tr("Your computer will now install the USB networking driver. If everything goes fine, congratulations, you have a new network device available in the devices-list.");
-		if(QMessageBox::question(this, title, text, QMessageBox::Yes | QMessageBox::Cancel) != QMessageBox::Yes)
-			throw QString();
-
-		text = tr("You are now ready to use the program in USB mode with your Windows. Just remember to never use pc-suite/mass-storage modes when you enable USB networking.");
-		if(QMessageBox::question(this, title, text, QMessageBox::Yes | QMessageBox::Cancel) != QMessageBox::Yes)
-			throw QString();
-
-		text = tr("Windows should not need more configuration in order to be used with qtmobilehotspot. Simply run qtmobilehotspot, start in USB mode, plug your N900 into your PC, and enjoy.");
-		if(QMessageBox::question(this, title, text, QMessageBox::Yes | QMessageBox::Cancel) != QMessageBox::Yes)
-			throw QString();
-
-		text = tr("Please note that if you are already using MADDE on your computer, you may have to reset your new network card settings to automatic.");
-		if(QMessageBox::question(this, title, text, QMessageBox::Yes | QMessageBox::Cancel) != QMessageBox::Yes)
-			throw QString();
-	}
-	catch(QString fail){
-		qDebug("WARNING : Interrupted Windows USB Assistant");
-		failed = true;
-	}
-
-	text = tr("Please disconnect your N900 from your computer. We are going to unload the USB module and load the normal Nokia one. Do not choose any USB mode if you plan to use qtmobilehotspot.");
-	if(! failed)
-		QMessageBox::information(this, title, text);
-	HotspotHelper::unprepareUSBInterface(configuration);
-	HotspotHelper::unloadStandardUSB();
-	HotspotHelper::loadNokiaUSB();
-
-	configuration.lanInterface = interface;
+void MobileHotspotGUI::configureInternetAccess(){
+	internetAccessGUI = new InternetAccessGUI(this);
+	internetAccessGUI->setConfiguration(configuration);
+	connect(internetAccessGUI, SIGNAL(windowClosed()),
+		this, SLOT(configureInternetAccessFinished()));
+	internetAccessGUI->show();
 }
 
-void MobileHotspotGUI::configureInternetAccess(){
-	InternetAccessGUI gui(this);
-	gui.setConfiguration(configuration);
-	if(gui.exec() != QDialog::Accepted)
-		return;
-
-	gui.configuration(&configuration);
+void MobileHotspotGUI::configureInternetAccessFinished(){
+	internetAccessGUI->configuration(&configuration);
 	configuration.save();
 	updateDisplayedConfiguration();
 }
 
 void MobileHotspotGUI::configureAccessPoint(){
-	AccessPointGUI gui(this);
-	gui.setConfiguration(configuration);
-	if(gui.exec() != QDialog::Accepted)
-		return;
+	accessPointGUI = new AccessPointGUI(this);
+	accessPointGUI->setConfiguration(configuration);
+	connect(accessPointGUI, SIGNAL(windowClosed()),
+		this, SLOT(configureAccessPointFinished()));
+	accessPointGUI->show();
+}
 
-	gui.configuration(&configuration);
+void MobileHotspotGUI::configureAccessPointFinished(){
+	accessPointGUI->configuration(&configuration);
 	configuration.save();
 	updateDisplayedConfiguration();
 }
@@ -303,14 +232,6 @@ void MobileHotspotGUI::configureInterface(int index){
 
 void MobileHotspotGUI::start(bool notification){
 	int ret;
-	/** Find previous enforcement **/
-	if(configuration.internetEnabled && configuration.enforcement2g3g != ENFORCEMENT_2G3G_IGNORE){
-		ret = DBUSHelper::internetEnforcement2G3G(&previousEnforcement);
-		if(ret != 0){
-			qDebug("WARNING : Cannot get the current level of 2G/3G enforcement, using default value DOUBLE");
-			previousEnforcement = DBUS_2G3G_DOUBLE;
-		}
-	}
 
 	/** Find previous connection **/
 	previousConnectionID = "";
@@ -349,10 +270,12 @@ void MobileHotspotGUI::startProcedure(){
 	QListIterator<QString> pluginsIterator = QListIterator<QString>(sortedPlugins);
 	while(pluginsIterator.hasNext()){
 		MobileHotspotPlugin *plugin = plugins.value(pluginsIterator.next());
-		qDebug( (QString("Plugin beforeStarting : ") + plugin->name()).toAscii().data() );
-		qApp->installTranslator(plugin->translator());
-			plugin->beforeStarting(configuration);
-		qApp->removeTranslator(plugin->translator());
+		if(plugin->isPluginEnabled()){
+			qDebug( (QString("Plugin beforeStarting : ") + plugin->name()).toAscii().data() );
+			qApp->installTranslator(plugin->translator());
+				plugin->beforeStarting(&configuration);
+			qApp->removeTranslator(plugin->translator());
+		}
 	}
 
 	try{
@@ -410,11 +333,8 @@ void MobileHotspotGUI::startProcedure(){
 			if(ret != 0)
 				throw QString(tr("Error while loading standard g_ether driver"));
 
-			/** Bypass USB-mode window **/
-			QTimer::singleShot(1, this, SLOT(bypassUSBModeWindow()));
-
 			/** Prepare USB interface **/
-			ret = HotspotHelper::prepareUSBInterface(configuration);
+			ret = HotspotHelper::prepareUSBInterface(configuration.usbMAC, configuration.lanNetwork);
 			if(ret != 0)
 				throw QString(tr("Error while preparing the USB interface"));
 
@@ -453,31 +373,18 @@ void MobileHotspotGUI::startProcedure(){
 	pluginsIterator = QListIterator<QString>(sortedPlugins);
 	while(pluginsIterator.hasNext()){
 		MobileHotspotPlugin *plugin = plugins.value(pluginsIterator.next());
-		qDebug( (QString("Plugin afterStarting : ") + plugin->name()).toAscii().data() );
-		qApp->installTranslator(plugin->translator());
-			plugin->afterStarting(configuration, successStarting);
-		qApp->removeTranslator(plugin->translator());
-	}
-
-	/** Enforcement 2G/3G **/
-	if(configuration.internetEnabled && configuration.enforcement2g3g != ENFORCEMENT_2G3G_IGNORE && configuration.internetInterface() == configuration.INTERFACE_GPRS){
-		qDebug("Changing 2g/3g enforcement");
-		ret = 0;
-		if(configuration.enforcement2g3g == ENFORCEMENT_2G3G_2G && previousEnforcement != DBUS_2G3G_2G)
-			ret = DBUSHelper::setInternetEnforcement2G3G(DBUS_2G3G_2G);
-		else if(configuration.enforcement2g3g == ENFORCEMENT_2G3G_3G && previousEnforcement != DBUS_2G3G_3G)
-			ret = DBUSHelper::setInternetEnforcement2G3G(DBUS_2G3G_3G);
-		else if(configuration.enforcement2g3g == ENFORCEMENT_2G3G_DOUBLE && previousEnforcement != DBUS_2G3G_DOUBLE)
-			ret = DBUSHelper::setInternetEnforcement2G3G(DBUS_2G3G_DOUBLE);
-		if(ret != 0)
-			qDebug("WARNING : Cannot change 2g/3g enforcement");
+		if(plugin->isPluginEnabled()){
+			qDebug( (QString("Plugin afterStarting : ") + plugin->name()).toAscii().data() );
+			qApp->installTranslator(plugin->translator());
+				plugin->afterStarting(&configuration, successStarting);
+			qApp->removeTranslator(plugin->translator());
+		}
 	}
 
 	/** GUI **/
 	if(success){
 		if(showNotifications)
 			DBUSHelper::notificationSimple(tr("Hotspot started successfully"));
-		displayPlugins(true);
 		ui.btnAccessPoint->setEnabled(false);
 		ui.btnInternetAccess->setEnabled(false);
 		ui.lstInterfaces->setEnabled(false);
@@ -509,10 +416,12 @@ void MobileHotspotGUI::stopProcedure(){
 	pluginsIterator.toBack();
 	while(pluginsIterator.hasPrevious()){
 		MobileHotspotPlugin *plugin = plugins.value(pluginsIterator.previous());
-		qDebug( (QString("Plugin beforeStopping : ") + plugin->name()).toAscii().data() );
-		qApp->installTranslator(plugin->translator());
-			plugin->beforeStopping(configuration, successStarting);
-		qApp->removeTranslator(plugin->translator());
+		if(plugin->isPluginEnabled()){
+			qDebug( (QString("Plugin beforeStopping : ") + plugin->name()).toAscii().data() );
+			qApp->installTranslator(plugin->translator());
+				plugin->beforeStopping(&configuration, successStarting);
+			qApp->removeTranslator(plugin->translator());
+		}
 	}
 
 	/** Unset iptables **/
@@ -537,7 +446,7 @@ void MobileHotspotGUI::stopProcedure(){
 	if(configuration.lanInterface == configuration.INTERFACE_USB){
 
 		/** Unprepare USB interface **/
-		ret = HotspotHelper::unprepareUSBInterface(configuration);
+		ret = HotspotHelper::unprepareUSBInterface();
 		if(ret != 0){
 			qDebug("Error while unpreparing USB interface");
 			success = false;
@@ -629,24 +538,17 @@ void MobileHotspotGUI::stopProcedure(){
 	pluginsIterator.toBack();
 	while(pluginsIterator.hasPrevious()){
 		MobileHotspotPlugin *plugin = plugins.value(pluginsIterator.previous());
-		qDebug( (QString("Plugin afterStopping : ") + plugin->name()).toAscii().data() );
-		qApp->installTranslator(plugin->translator());
-			plugin->afterStopping(configuration, successStarting, success);
-		qApp->removeTranslator(plugin->translator());
-	}
-
-	/** Enforcement 2G/3G **/
-	if(configuration.internetEnabled && configuration.enforcement2g3g != ENFORCEMENT_2G3G_IGNORE && configuration.internetInterface() == configuration.INTERFACE_GPRS){
-		qDebug("Restoring original 2g/3g enforcement");
-		ret = DBUSHelper::setInternetEnforcement2G3G(previousEnforcement);
-		if(ret != 0)
-			qDebug("WARNING : Cannot restore previous 2g/3g enforcement");
+		if(plugin->isPluginEnabled()){
+			qDebug( (QString("Plugin afterStopping : ") + plugin->name()).toAscii().data() );
+			qApp->installTranslator(plugin->translator());
+				plugin->afterStopping(&configuration, successStarting, success);
+			qApp->removeTranslator(plugin->translator());
+		}
 	}
 
 	/** GUI **/
 	if(showNotifications)
 		DBUSHelper::notificationSimple(success ? tr("Hotspot stopped successfully") : tr("Hotspot stopped with errors"));
-	displayPlugins(false);
 	ui.btnAccessPoint->setEnabled(true);
 	ui.btnInternetAccess->setEnabled(true);
 	ui.lstInterfaces->setEnabled(true);
@@ -689,6 +591,3 @@ void MobileHotspotGUI::previousConnectionRequest(){
 	dbus.send(msg);
 }
 
-void MobileHotspotGUI::bypassUSBModeWindow(){
-	//TODO
-}
