@@ -10,9 +10,13 @@
 #include <QtCore/QMap>
 #include <QtGui/QAction>
 #include <QtDBus/QDBusMessage>
+#include <QtCore/QTranslator>
 #include "dbushelper.h"
 #include "mobilehotspotconfiguration.h"
 #include "mobilehotspotplugin.h"
+#include "pluginscontrolgui.h"
+#include "accesspointgui.h"
+#include "internetaccessgui.h"
 #include "ui_mobilehotspotgui.h"
 
 
@@ -28,18 +32,23 @@ private:
 	void updateDisplayedConfiguration();
 	void loadPlugins();
 	void sortPlugins();
-	void displayPlugins(bool running);
 	void previousConnectionEnableSignal();
 	void previousConnectionDisableSignal();
 	void previousConnectionRequest();
 
 	Ui::MobileHotspotGUIClass ui;
+	QTranslator translator;
+
+	PluginsControlGUI *pluginsControlGUI;
+	AccessPointGUI *accessPointGUI;
+	InternetAccessGUI *internetAccessGUI;
+
     QMap<QString, MobileHotspotPlugin*> plugins;
     QList<QString> sortedPlugins;
+    QMap<QString, QString> pluginsTranslatorsBaseNames;
 
     MobileHotspotConfiguration configuration;
 
-    Enforcement2G3G previousEnforcement;
     QStringList alreadyLoadedModules;
     int scanInterval;
     QProcess *dnsmasqProcess;
@@ -56,16 +65,19 @@ protected :
         void closeEvent(QCloseEvent* event);
 
 private slots:
-	void usbWindowsAssistant();
+	void configureLanguage();
+	void configureLanguageFinished(bool saveConfiguration);
+	void configurePlugins();
+	void configurePluginsFinished();
 	void configureAccessPoint();
+	void configureAccessPointFinished();
 	void configureInternetAccess();
+	void configureInternetAccessFinished();
 	void configureInterface(int index);
-	void pluginTriggered();
 	void start(bool notification = true);
 	void startProcedure();
 	void stop(bool notification = true);
 	void stopProcedure();
-	void bypassUSBModeWindow();
 	void previousConnectionSignal(const QDBusMessage &message);
 };
 
