@@ -1,11 +1,14 @@
+#include <QtGui/QCloseEvent>
+#include <QtGui/QMenuBar>
 #include "plugingui.h"
 #include "pluginconfiguration.h"
 
 
 PluginGUI::PluginGUI(QWidget *parent)
-    : QDialog(parent)
+    : QMainWindow(parent)
 {
 	ui.setupUi(this);
+	this->setAttribute(Qt::WA_Maemo5StackedWindow);
 }
 
 PluginGUI::~PluginGUI()
@@ -13,6 +16,14 @@ PluginGUI::~PluginGUI()
 
 }
 
+void PluginGUI::closeEvent(QCloseEvent* event){
+	// Signal that the GUI is closed
+	if(menuBar() != 0)
+		menuBar()->clear(); // Solves a bug where menubar in child gui is kept in parent gui
+	emit windowClosed();
+	event->accept();
+}
+
 void PluginGUI::configuration(PluginConfiguration *conf){
 	// Store entered configuration into the configuration object
 	// conf->some_variable = ui.some_component->someGetter();
@@ -22,3 +33,4 @@ void PluginGUI::setConfiguration(PluginConfiguration &conf){
 	// Display configuration from the configuration object
 	// ui.some_component->someSetter(conf.some_variable);
 }
+
