@@ -7,8 +7,7 @@
 
 enum MacFilterMode{
 	MODE_ALLOW,
-	MODE_DENY,
-	MODE_DISABLED
+	MODE_DENY
 };
 
 
@@ -19,6 +18,7 @@ public:
 	~PluginConfiguration();
 	void save();
 	void load();
+	void reset();
 
 	MacFilterMode filterMode;
 	QStringList mactable;
