@@ -5,6 +5,14 @@
 #include "../../qtMobileHotspot/src/mobilehotspotpluginhelper.h"
 
 
+enum Enforcement_2G3G{
+	ENFORCEMENT_2G3G_2G,
+	ENFORCEMENT_2G3G_3G,
+	ENFORCEMENT_2G3G_DOUBLE,
+	ENFORCEMENT_2G3G_IGNORE
+};
+
+
 class PluginConfiguration{
 
 public:
@@ -12,10 +20,13 @@ public:
 	~PluginConfiguration();
 	void save();
 	void load();
+	void reset();
+
 	bool disablePowerSaving;
 	bool internetPing;
 	QString internetPingIP;
 	bool wlanCheck;
+	Enforcement_2G3G enforcement2g3g;
 
 private:
 	MobileHotspotPluginHelper *helper; // Helper for this plugin
