@@ -13,10 +13,20 @@ PluginConfiguration::~PluginConfiguration(){
 	// helper deletion is handled by plugin itself, no need to destroy it here
 }
 
+void PluginConfiguration::reset(){
+	// Reset the plugin's configuration, by deleting the saved one and calling load()
+	helper->deleteConfiguration(); // Delete saved configuration
+
+	// You may want to do some things here before calling load, such as freeing memory
+	// Type here your customized code
+	// delete myVariable;
+
+	load(); // Load configuration (the default one, as none is saved)
+}
+
 void PluginConfiguration::load(){
 	// Load the plugin's configuration, please use the helper function load("settingName", "defaultValue")
 	// some_variable = helper->load("settingName", "default value").toString();
-	enabled = helper->load("enabled", "no").toString() == "yes";
 	port = helper->load("port", (int)8118).toInt();
 	ports = helper->load("ports", "80, 8080").toString();
 	QString agent = helper->load("ua", "nochange").toString();
@@ -38,7 +48,6 @@ void PluginConfiguration::load(){
 void PluginConfiguration::save(){
 	// Save the plugin's configuration, please use the helper function save("settingName", value)
 	// helper->save("settingName", some_variable);
-	helper->save("enabled", enabled ? "yes" : "no");
 	helper->save("port", port);
 	helper->save("ports", ports);
 	if(ua == UA_NOCHANGE)
