@@ -19,13 +19,13 @@ class PrivoxyHelper{
 public:
 	PrivoxyHelper();
 	~PrivoxyHelper();
-	static int generateConfigurationFile(const MobileHotspotConfiguration &configuration, PluginConfiguration *conf);
-	static int deleteConfigurationFile(const MobileHotspotConfiguration &configuration, PluginConfiguration *conf);
-	static int generateActionFile(const MobileHotspotConfiguration &configuration, PluginConfiguration *conf);
-	static int deleteActionFile(const MobileHotspotConfiguration &configuration, PluginConfiguration *conf);
-	static int runPrivoxy(const MobileHotspotConfiguration &configuration, PluginConfiguration *conf, QProcess *process);
-	static int stopPrivoxy(const MobileHotspotConfiguration &configuration, PluginConfiguration *conf, QProcess *process);
-	static int setIptables(const MobileHotspotConfiguration &configuration, PluginConfiguration *conf);
+	static int generateConfigurationFile(const MobileHotspotConfiguration *configuration, PluginConfiguration *conf);
+	static int deleteConfigurationFile(const MobileHotspotConfiguration *configuration, PluginConfiguration *conf);
+	static int generateActionFile(const MobileHotspotConfiguration *configuration, PluginConfiguration *conf);
+	static int deleteActionFile(const MobileHotspotConfiguration *configuration, PluginConfiguration *conf);
+	static int runPrivoxy(const MobileHotspotConfiguration *configuration, PluginConfiguration *conf, QProcess *process);
+	static int stopPrivoxy(const MobileHotspotConfiguration *configuration, PluginConfiguration *conf, QProcess *process);
+	static int setIptables(const MobileHotspotConfiguration *configuration, PluginConfiguration *conf);
 };
 
 #endif // PRIVOXYHELPER_H
